<?php

namespace App\OrdersManagement\Domain\Order;

use App\OrdersManagement\Domain\Product\Product;
use App\Query;
use Exception;
use App\BaseMapper;
use App\QueryFactory;
use App\Response\Response;
use App\OrdersManagement\Routines\Routines;
use App\Exceptions\RoutineQueryException;

class Mapper extends BaseMapper
{
    public $modelClass = Order::class;

    /**
     * query
     *
     * @return OrderQuery
     */
    public function query(): Query
    {
        return QueryFactory::create(OrderQuery::class, $this);
    }

    /**
     * find
     *
     * @param array $parameters
     * @return Response
     * @throws RoutineQueryException|Exception
     */
    public function find(array $parameters): Response
    {
        // table: orders
        $query = Routines::SP_GET_ORDER;
        return $this->get($query, $parameters)
            ->mapInto($this->modelClass);
    }

    /**
     * save
     *
     * @param array $parameters
     * @return Response
     * @throws RoutineQueryException|Exception
     */
    public function save(array $parameters): Response
    {
        // table: orders
        $query = Routines::SP_SET_ORDERS;
        return $this->set($query, $parameters)
            ->mapInto($this->modelClass);
    }

    /**
     * destroy
     *
     * @param array $parameters
     * @return Response
     * @throws RoutineQueryException|Exception
     */
    public function destroy(array $parameters): Response
    {
        // table: orders
        $query = Routines::SP_DEL_ORDER;
        return $this->del($query, $parameters);
    }

    /**
     * attachProduct
     *
     * @param array $parameters
     * @return Response
     * @throws RoutineQueryException|Exception
     */
    public function attachProduct(array $parameters): Response
    {
        // table: orders_products_related
        $query = Routines::SP_SET_PRODUCTS_TO_ORDERS;
        $qr = $this->set($query, $parameters)
            ->mapInto(Product::class);
        if ($qr->returnCode() == Order::DUPLICATED_PRODUCT) {
            throw new ProductAttachedException("Product already attached to order", $qr->returnCode());
        }
        return $qr;
    }

    /**
     * detachProduct
     *
     * @param array $parameters
     * @return Response
     * @throws RoutineQueryException|Exception
     */
    public function detachProduct(array $parameters): Response
    {
        // table: orders_products_related
        $query = Routines::SP_DEL_PRODUCT_FROM_ORDER;
        return $this->del($query, $parameters);
    }

    /**
     * query
     *
     * @return OrderQuery
     */
    public function queryProducts(): Query
    {
        return QueryFactory::create(ProductQuery::class, $this);
    }
}
