<?php

namespace App\OrdersManagement\Domain\Product;

use App\Query;
use Exception;
use App\BaseMapper;
use App\QueryFactory;
use App\Response\Response;
use App\OrdersManagement\Routines\Routines;
use App\Exceptions\RoutineQueryException;

class Mapper extends BaseMapper
{
    public $modelClass = Product::class;

    /**
     * query
     *
     * @return ProductQuery
     */
    public function query(): Query
    {
        return QueryFactory::create(ProductQuery::class, $this);
    }

    /**
     * find
     *
     * @param array $parameters
     * @return Response
     * @throws RoutineQueryException|Exception
     */
    public function find(array $parameters): Response
    {
        // table: products
        $query = Routines::SP_GET_PRODUCT;
        return $this->get($query, $parameters)
            ->mapInto($this->modelClass);
    }

    /**
     * save
     *
     * @param array $parameters
     * @return Response
     * @throws RoutineQueryException|Exception
     */
    public function save(array $parameters): Response
    {
        // table: products
        $query = Routines::SP_SET_PRODUCTS;
        return $this->set($query, $parameters)
            ->mapInto($this->modelClass);
    }

    /**
     * destroy
     *
     * @param array $parameters
     * @return Response
     * @throws RoutineQueryException|Exception
     */
    public function destroy(array $parameters): Response
    {
        // table: products
        $query = Routines::SP_DEL_PRODUCT;
        return $this->del($query, $parameters);
    }

}
