<?php

namespace App\OrdersManagement\Domain\Supplier;

use App\Query;
use App\QueryFactory;
use Exception;
use App\BaseMapper;
use App\Response\Response;
use App\OrdersManagement\Routines\Routines;
use App\Exceptions\RoutineQueryException;

class Mapper extends BaseMapper
{
    public $modelClass = Supplier::class;

    /**
     * query
     *
     * @return SupplierQuery
     */
    public function query(): Query
    {
        return QueryFactory::create(SupplierQuery::class, $this);
    }

    /**
     * find
     *
     * @param array $parameters
     * @return Response
     * @throws RoutineQueryException|Exception
     */
    public function find(array $parameters): Response
    {
        // table: suppliers
        $query = Routines::SP_GET_SUPPLIER;
        return $this->get($query, $parameters)
            ->mapInto($this->modelClass);
    }

    /**
     * save
     *
     * @param array $parameters
     * @return Response
     * @throws RoutineQueryException|Exception
     */
    public function save(array $parameters): Response
    {
        // table: suppliers
        $query = Routines::SP_SET_SUPPLIERS;
        return $this->set($query, $parameters)
            ->mapInto($this->modelClass);
    }

    /**
     * destroy
     *
     * @param array $parameters
     * @return Response
     * @throws RoutineQueryException|Exception
     */
    public function destroy(array $parameters): Response
    {
        // table: suppliers
        $query = Routines::SP_DEL_SUPPLIER;
        return $this->del($query, $parameters);
    }
}
