<?php


namespace App\OrdersManagement\Domain\Supplier;

use Illuminate\Database\Eloquent\Model;

class Supplier extends Model
{
    const NEW = -1;

    /**
     * Indicates if the IDs are auto-incrementing.
     *
     * @var bool
     */
    public $incrementing = false;

    /**
     * The connection name for the model.
     *
     * @var string|null
     */
    protected $connection = 'default';

    /**
     * The attributes that aren't mass assignable.
     *
     * @var string[]|bool
     */
    protected $guarded = [];

    /**
     * The attributes that should be cast.
     *
     * @var array
     */
    protected $casts = [
        'register_date' => 'datetime:' . \DateTimeInterface::ISO8601,
        'update_date' => 'datetime:' . \DateTimeInterface::ISO8601,
    ];

    /**
     * The storage format of the model's date columns.
     *
     * @var string
     */
    protected $dateFormat = \DateTimeInterface::ISO8601;

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array
     */
    protected $hidden = [];

    /**
     *
     * @return string
     */
    public function getNameAttribute()
    {
        return html_entity_decode($this->attributes['name'], ENT_COMPAT, 'UTF-8');
    }

    /**
     *
     * @return string
     */
    public function getCompanyNameAttribute()
    {
        return html_entity_decode($this->attributes['company_name'], ENT_COMPAT, 'UTF-8');
    }

    /**
     *
     * @return string
     */
    public function getBrandNameAttribute()
    {
        return html_entity_decode($this->attributes['brand_name'], ENT_COMPAT, 'UTF-8');
    }

    /**
     *
     * @return string
     */
    public function getDescriptionAttribute()
    {
        return html_entity_decode($this->attributes['description'], ENT_COMPAT, 'UTF-8');
    }

    /**
     *
     * @return string
     */
    public function getAddressAttribute()
    {
        return html_entity_decode($this->attributes['address'], ENT_COMPAT, 'UTF-8');
    }

    /**
     *
     * @return string
     */
    public function getCityAttribute()
    {
        return html_entity_decode($this->attributes['city'], ENT_COMPAT, 'UTF-8');
    }

}
